@@ -2,7 +2,7 @@ package Minilla;
 use strict;
 use warnings;
 use 5.010001;
-use version; our $VERSION = version->declare("v3.1.9");
+use version; our $VERSION = version->declare("v3.1.10");
 
 our $DEBUG;
 our $AUTO_INSTALL;
@@ -46,7 +46,7 @@ As stated above, Minilla is opinionated. Minilla has a bold assumption and conve
 
 =item Your executable files are in I<script/> directory, if any
 
-=item Your module is maintained with B<Git> and C<git ls-files> matches with what you will release
+=item Your module is maintained with B<Git>, C<git ls-files> matches with what you will release, your remote is named I<origin> and your main branch is named I<master>
 
 =item Your module has a static list of prerequisites that can be described in L<cpanfile>
 
@@ -256,9 +256,9 @@ See L<CPAN::Meta::Spec>.
 
 =item badges
 
-    badges = ['travis-ci.com', 'travis-ci.org', 'circleci', 'appveyor', 'coveralls', 'codecov', 'gitter', 'metacpan', 'kritika', 'github-actions/$workflow_name']
+    badges = ['travis-ci.com', 'travis-ci.org', 'circleci', 'appveyor', 'coveralls', 'codecov', 'gitter', 'metacpan', 'kritika', 'github-actions/$workflow_name', 'gitlab-pipeline', 'gitlab-coverage']
 
-Embed badges image (e.g. Travis-CI) to README.md. It ought to be array and each elements must be service name. Now, supported services are 'travis-ci.com', 'travis-ci.org', 'circleci', 'appveyor', 'coveralls', 'codecov', 'gitter', 'metacpan' and 'kritika'.
+Embed badges image (e.g. Travis-CI) to README.md. It ought to be array and each elements must be service name. Now, supported services are 'travis-ci.com', 'travis-ci.org', 'circleci', 'appveyor', 'coveralls', 'codecov', 'gitter', 'metacpan', 'kritika' 'github-actions', 'gitlab-pipeline' and 'gitlab-coverage'.
 
 You can send additional parameters as required by your CI provider by including a
 query string along with your service name: e.g. C<travis?token=[YOUR_TOKEN_GOES_HERE]&branch=dev>
